Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var RootCmd = &cobra.Command{ Use: "kubewatch", Short: "A watcher for Kubernetes", Long: ` Kubewatch: A watcher for Kubernetes kubewatch is a Kubernetes watcher that could publishes notification to Slack/hipchat/mattermost/flock channels. It watches the cluster for resource changes and notifies them through webhooks. supported webhooks: - slack - hipchat - mattermost - flock - webhook `, Run: func(cmd *cobra.Command, args []string) { config := &config.Config{} if err := config.Load(); err != nil { logrus.Fatal(err) } config.CheckMissingResourceEnvvars() c.Run(config) }, }
RootCmd represents the base command when called without any subcommands
Functions ¶
func Execute ¶
func Execute()
Execute adds all child commands to the root command sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.
Types ¶
This section is empty.
Source Files
¶
- config.go
- flock.go
- hipchat.go
- mattermost.go
- msteams.go
- resource.go
- root.go
- slack.go
- smtp.go
- version.go
- webhook.go
Click to show internal directories.
Click to hide internal directories.