Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Event ¶
type Event struct {
Namespace string
Kind string
Component string
Host string
Reason string
Status interface{}
Level string
Name string
}
Event represent an event got from k8s api server Events from different endpoints need to be casted to KubewatchEvent before being able to be handled by handler
Source Files
¶
- event.go
Click to show internal directories.
Click to hide internal directories.